@@ -145,9 +145,7 @@ class ProcessForm(UniversalProcessor):
         
     def delete_page(self):
         page = ds.con.Pages()
-        t_con = ds.con.Templates()
-        template = t_con.get_cfile_fid(self.fields['page-template-id'].value)
-        self._delete_file(page, None, 'page-name', repo = template.repo)
+        self._delete_file(page, 'repo', 'page-name')
         
     def edit_template_gen(self):
         cfile = self._edit_template()
@@ -180,7 +178,8 @@ class ProcessForm(UniversalProcessor):
         
     def edit_static(self):
         cfile = self._edit_static()
-        self._add_msg('"%s" successfully saved' % cfile.display, 'success')
+        if cfile:
+            self._add_msg('"%s" successfully saved' % cfile.display, 'success')
         
     def _edit_static(self):
         static = ds.con.Statics()
